@@ -1,12 +1,18 @@
 import contextlib
 import math
 import os
+import select
 import statistics
 import sys
+import sysconfig
+import time
 from shlex import quote as shell_quote   # noqa
 from shutil import which
 
-
+# Currently there is a packaging issue for PEP-703,
+# Until then psutil is disabled as a workaround.
+# See: https://github.com/python/cpython/issues/116024
+USE_PSUTIL = not bool(sysconfig.get_config_var('Py_GIL_DISABLED'))
 MS_WINDOWS = (sys.platform == 'win32')
 MAC_OS = (sys.platform == 'darwin')
 
@@ -151,7 +157,7 @@ def read_first_line(path, error=False):
         with open_text(path) as fp:
             line = fp.readline()
         return line.rstrip()
-    except IOError:
+    except OSError:
         if error:
             raise
         else:
@@ -262,8 +268,12 @@ def create_environ(inherit_environ, locale, copy_all):
     if copy_all:
         return os.environ
     env = {}
-
-    copy_env = ["PATH", "PYTHONPATH", "HOME", "TEMP", "COMSPEC", "SystemRoot", "SystemDrive"]
+    copy_env = ["PATH", "HOME", "TEMP", "COMSPEC", "SystemRoot", "SystemDrive",
+                # Python specific variables
+                "PYTHONPATH", "PYTHON_CPU_COUNT", "PYTHON_GIL",
+                # Pyperf specific variables
+                "PYPERF_PERF_RECORD_DATA_DIR", "PYPERF_PERF_RECORD_EXTRA_OPTS",
+                ]
     if locale:
         copy_env.extend(('LANG', 'LC_ADDRESS', 'LC_ALL', 'LC_COLLATE',
                          'LC_CTYPE', 'LC_IDENTIFICATION', 'LC_MEASUREMENT',
@@ -278,7 +288,7 @@ def create_environ(inherit_environ, locale, copy_all):
     return env
 
 
-class _Pipe(object):
+class _Pipe:
     _OPEN_MODE = "r"
 
     def __init__(self, fd):
@@ -315,6 +325,36 @@ class ReadPipe(_Pipe):
         self._file = file
         return file
 
+    def read_text(self, timeout=None):
+        if timeout is not None:
+            return self._read_text_timeout(timeout)
+        else:
+            with self.open_text() as rfile:
+                return rfile.read()
+
+    def _read_text_timeout(self, timeout):
+        fd = self.fd
+        os.set_blocking(fd, False)
+
+        start_time = time.monotonic()
+        output = []
+        while True:
+            if time.monotonic() - start_time > timeout:
+                raise TimeoutError(f"Timed out after {timeout} seconds")
+            ready, _, _ = select.select([fd], [], [], timeout)
+            if not ready:
+                continue
+            try:
+                data = os.read(fd, 1024)
+            except BlockingIOError:
+                continue
+            if not data:
+                break
+            output.append(data)
+
+        data = b"".join(output)
+        return data.decode("utf8")
+
 
 class WritePipe(_Pipe):
     def to_subprocess(self):
